@@ -425,11 +425,11 @@ class RuleCondorcetVtbIRV(Rule):
 
     # TODO: should be implemented .
 
-    # def _um_preliminary_checks_general_subclass_(self):
-    #     if equal_false(self.irv_.is_cm_):
-    #         self._is_um = False
-    #         self._candidates_um[:] = False
-    #         self._um_was_computed_with_candidates = True
+    def _um_preliminary_checks_general_subclass_(self):
+        if equal_false(self.irv_.is_cm_):
+            self._is_um = False
+            self._candidates_um[:] = False
+            self._um_was_computed_with_candidates = True
 
     # %% Ignorant-Coalition Manipulation (ICM)
 
