@@ -215,7 +215,7 @@ class RuleWoodall(Rule):
     def __init__(self, **kwargs):
         super().__init__(
             with_two_candidates_reduces_to_plurality=True, is_based_on_rk=True,
-            precheck_um=False, precheck_icm=False,
+            precheck_icm=False,
             log_identity="WOODALL", **kwargs
         )
 
@@ -294,6 +294,24 @@ class RuleWoodall(Rule):
 
     # %% Coalition Manipulation (CM)
 
+    def _cm_preliminary_checks_c_subclass_(self, c, optimize_bounds):
+        """CM: preliminary checks for challenger ``c``.
+
+        Let us consider the case where `w` is the Condorcet winner (rk ctb) (otherwise it is easy to manipulate, at
+        least if utility preferences are strict). We must have `c` in the (manipulated) Smith Set, hence we must have
+        `w` too. Hence we must manipulate IRV so that `w` is eliminated before `c`. In other words, at some point,
+        `w` must be eliminated, IRV-style, at a moment where `c` is still present in the election.
+        """
+        if self.cm_option != 'fast':
+            if (
+                self.w_ == self.profile_.condorcet_winner_rk_ctb
+                and not self.profile_.c_might_be_there_when_cw_is_eliminated_irv_style[c]
+            ):
+                # Impossible to manipulate with n_m manipulators
+                n_m = self.profile_.matrix_duels_ut[c, self.w_]
+                self._update_necessary(self._necessary_coalition_size_cm, c, n_m + 1,
+                                       'CM: Update necessary_coalition_size_cm[c] = n_m + 1 =')
+
     @property
     def losing_candidates_(self):
         """If ``irv_.w_ does not win, then we put her first. Other losers are sorted as usual. (scores in
